<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Mezze
 * @since Mezze 1.0.0
 * @return array An array of default values
 */

function mezze_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$mezze_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'mezze' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'mezze' ),
		'read_more_text' 				=> esc_html__( 'Read Full Article', 'mezze' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Slider
		'slider_section_enable'			=> false,
		'circle_image_enable'			=> false,
		'shadow_image_enable'			=> false,
		'slider_btn_label'				=> esc_html__( 'Check Details', 'mezze' ),

		// About
		'about_section_enable'			=> false,
		'about_btn_title'				=> esc_html__( 'See More', 'mezze' ),

		// Special Menu
		'special_menu_section_enable'	=> false,
		'special_menu_content_type'		=> 'page',
		'special_menu_title'			=> esc_html__( 'Explore Delicious Flavour', 'mezze' ),

		// service
		'service_section_enable'		=> false,
		'service_title'					=> esc_html__( 'For Your Comfort', 'mezze' ),

		// blog
		'blog_section_enable'			=> false,
		'blog_content_type'				=> 'category',
		'blog_title'					=> esc_html__( 'Latest Blog Posts', 'mezze' ),
		'blog_readmore'					=> esc_html__( 'Read Full Article', 'mezze' ),

	);

	$output = apply_filters( 'mezze_default_theme_options', $mezze_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}